@@ -55,6 +55,9 @@
 #' 
 #' @examples
 #' \dontrun{
+#' # Only run example if R package 'Rgraphviz' from Bioconductor is available
+#' #
+#' if (requireNamespace("Rgraphviz", quietly = TRUE)) {
 #' # Define order of treatments in depression dataset dat.linde2015
 #' #
 #' trts <- c("TCA", "SSRI", "SNRI", "NRI",
@@ -66,22 +69,22 @@
 #' 
 #' # (1) Early response
 #' #
-#' p1 <- pairwise(treat = list(treatment1, treatment2, treatment3),
+#' pw1 <- pairwise(treat = list(treatment1, treatment2, treatment3),
 #'   event = list(resp1, resp2, resp3),
 #'   n = list(n1, n2, n3),
 #'   studlab = id, data = dat.linde2015, sm = "OR")
 #' #
-#' net1 <- netmeta(p1, common = FALSE,
+#' net1 <- netmeta(pw1, common = FALSE,
 #'   seq = trts, ref = "Placebo", small.values = "undesirable")
 #' 
 #' # (2) Early remission
 #' #
-#' p2 <- pairwise(treat = list(treatment1, treatment2, treatment3),
+#' pw2 <- pairwise(treat = list(treatment1, treatment2, treatment3),
 #'   event = list(remi1, remi2, remi3),
 #'   n = list(n1, n2, n3),
 #'   studlab = id, data = dat.linde2015, sm = "OR")
 #' #
-#' net2 <- netmeta(p2, common = FALSE,
+#' net2 <- netmeta(pw2, common = FALSE,
 #'   seq = trts, ref = "Placebo", small.values = "undesirable")
 #' 
 #' # Partial order of treatment rankings
@@ -92,6 +95,7 @@
 #' #
 #' hasse(po)
 #' }
+#' }
 #' 
 #' @method hasse netposet
 #' @export
@@ -104,6 +108,18 @@ hasse.netposet <- function(x,
                            lwd = 1,
                            ...) {
   
+  if (!is_installed_package("Rgraphviz", stop = FALSE)) {
+    message(paste0("Package 'Rgraphviz' missing.",
+                   "\n  ",
+                   "Please use the following R commands for installation:",
+                   "\n  ",
+                   "install.packages(\"BiocManager\")",
+                   "\n  ",
+                   "BiocManager::install(\"Rgraphviz\")"))
+    #
+    return(invisible(NULL))
+  }
+  
   chkclass(x, "netposet")
   x <- updateversion(x)
   #
